# -*- coding:UTF-8 -*-
"""
Allure Handle - 轻量级 Allure 报告处理工具

一个简单易用的 Allure 报告工具，用于 pytest 测试框架。
最小依赖，只需要 allure-pytest。
"""
from allure_handle.allure_handle import AllureHandle, allure_handle

__version__ = '1.0.0'
__all__ = ['AllureHandle', 'allure_handle']

